"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _OriginProtocol:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OriginProtocolEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OriginProtocol.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ORIGIN_PROTOCOL_UNSPECIFIED: _OriginProtocol.ValueType  # 0
    HTTP: _OriginProtocol.ValueType  # 1
    """CDN servers will connect to your origin via HTTP."""
    HTTPS: _OriginProtocol.ValueType  # 2
    """CDN servers will connect to your origin via HTTPS."""
    MATCH: _OriginProtocol.ValueType  # 3
    """Connection protocol will be chosen automatically (content on the
    origin source should be available for the CDN both through HTTP and HTTPS).
    """

class OriginProtocol(_OriginProtocol, metaclass=_OriginProtocolEnumTypeWrapper):
    """This option defines the protocol that will be used by CDN servers to request
    content from an origin source. If not specified, we will use HTTP to connect
    to an origin server.
    """

ORIGIN_PROTOCOL_UNSPECIFIED: OriginProtocol.ValueType  # 0
HTTP: OriginProtocol.ValueType  # 1
"""CDN servers will connect to your origin via HTTP."""
HTTPS: OriginProtocol.ValueType  # 2
"""CDN servers will connect to your origin via HTTPS."""
MATCH: OriginProtocol.ValueType  # 3
"""Connection protocol will be chosen automatically (content on the
origin source should be available for the CDN both through HTTP and HTTPS).
"""
global___OriginProtocol = OriginProtocol

class _RewriteFlag:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RewriteFlagEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RewriteFlag.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REWRITE_FLAG_UNSPECIFIED: _RewriteFlag.ValueType  # 0
    LAST: _RewriteFlag.ValueType  # 1
    """Stops processing of the current set of ngx_http_rewrite_module directives and
    starts a search for a new location matching changed URI.
    """
    BREAK: _RewriteFlag.ValueType  # 2
    """Stops processing of the current set of the Rewrite option."""
    REDIRECT: _RewriteFlag.ValueType  # 3
    """Returns a temporary redirect with the 302 code; It is used when a replacement string does not start
    with "http://", "https://", or "$scheme".
    """
    PERMANENT: _RewriteFlag.ValueType  # 4
    """Returns a permanent redirect with the 301 code."""

class RewriteFlag(_RewriteFlag, metaclass=_RewriteFlagEnumTypeWrapper):
    """RewriteFlag defines flag for the Rewrite option."""

REWRITE_FLAG_UNSPECIFIED: RewriteFlag.ValueType  # 0
LAST: RewriteFlag.ValueType  # 1
"""Stops processing of the current set of ngx_http_rewrite_module directives and
starts a search for a new location matching changed URI.
"""
BREAK: RewriteFlag.ValueType  # 2
"""Stops processing of the current set of the Rewrite option."""
REDIRECT: RewriteFlag.ValueType  # 3
"""Returns a temporary redirect with the 302 code; It is used when a replacement string does not start
with "http://", "https://", or "$scheme".
"""
PERMANENT: RewriteFlag.ValueType  # 4
"""Returns a permanent redirect with the 301 code."""
global___RewriteFlag = RewriteFlag

class _SecureKeyURLType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SecureKeyURLTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SecureKeyURLType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SECURE_KEY_URL_TYPE_UNSPECIFIED: _SecureKeyURLType.ValueType  # 0
    ENABLE_IP_SIGNING: _SecureKeyURLType.ValueType  # 1
    """Use scpecific IP address in URL signing. URL will be availible only for this IP."""
    DISABLE_IP_SIGNING: _SecureKeyURLType.ValueType  # 2
    """Sign URL without using IP address. URL will be available for all IP addresses."""

class SecureKeyURLType(_SecureKeyURLType, metaclass=_SecureKeyURLTypeEnumTypeWrapper):
    """SecureKeyURLType defines type of the URL signing."""

SECURE_KEY_URL_TYPE_UNSPECIFIED: SecureKeyURLType.ValueType  # 0
ENABLE_IP_SIGNING: SecureKeyURLType.ValueType  # 1
"""Use scpecific IP address in URL signing. URL will be availible only for this IP."""
DISABLE_IP_SIGNING: SecureKeyURLType.ValueType  # 2
"""Sign URL without using IP address. URL will be available for all IP addresses."""
global___SecureKeyURLType = SecureKeyURLType

class _PolicyType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PolicyTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PolicyType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    POLICY_TYPE_UNSPECIFIED: _PolicyType.ValueType  # 0
    POLICY_TYPE_ALLOW: _PolicyType.ValueType  # 1
    """Allow access to all IP addresses except the ones specified in the excepted_values field."""
    POLICY_TYPE_DENY: _PolicyType.ValueType  # 2
    """Block access to all IP addresses except the ones specified in the excepted_values field."""

class PolicyType(_PolicyType, metaclass=_PolicyTypeEnumTypeWrapper):
    """PolicyType defines type of the policy in IP address acl rules."""

POLICY_TYPE_UNSPECIFIED: PolicyType.ValueType  # 0
POLICY_TYPE_ALLOW: PolicyType.ValueType  # 1
"""Allow access to all IP addresses except the ones specified in the excepted_values field."""
POLICY_TYPE_DENY: PolicyType.ValueType  # 2
"""Block access to all IP addresses except the ones specified in the excepted_values field."""
global___PolicyType = PolicyType

class _SSLCertificateType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SSLCertificateTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SSLCertificateType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SSL_CERTIFICATE_TYPE_UNSPECIFIED: _SSLCertificateType.ValueType  # 0
    """SSL certificate is unspecified."""
    DONT_USE: _SSLCertificateType.ValueType  # 1
    """No SSL certificate is added, the requests are sent via HTTP."""
    LETS_ENCRYPT_GCORE: _SSLCertificateType.ValueType  # 2
    """The option is deprecated. Works only if you have already pointed your domain name to the protected IP address in your DNS."""
    CM: _SSLCertificateType.ValueType  # 3
    """Add your SSL certificate by uploading the certificate in PEM format and your private key."""

class SSLCertificateType(_SSLCertificateType, metaclass=_SSLCertificateTypeEnumTypeWrapper):
    """A certificate type parameters."""

SSL_CERTIFICATE_TYPE_UNSPECIFIED: SSLCertificateType.ValueType  # 0
"""SSL certificate is unspecified."""
DONT_USE: SSLCertificateType.ValueType  # 1
"""No SSL certificate is added, the requests are sent via HTTP."""
LETS_ENCRYPT_GCORE: SSLCertificateType.ValueType  # 2
"""The option is deprecated. Works only if you have already pointed your domain name to the protected IP address in your DNS."""
CM: SSLCertificateType.ValueType  # 3
"""Add your SSL certificate by uploading the certificate in PEM format and your private key."""
global___SSLCertificateType = SSLCertificateType

class _SSLCertificateStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SSLCertificateStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SSLCertificateStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SSL_CERTIFICATE_STATUS_UNSPECIFIED: _SSLCertificateStatus.ValueType  # 0
    """SSL certificate is unspecified."""
    READY: _SSLCertificateStatus.ValueType  # 1
    """SSL certificate is ready to use."""
    CREATING: _SSLCertificateStatus.ValueType  # 2
    """The option is deprecated. SSL certificate is creating."""

class SSLCertificateStatus(_SSLCertificateStatus, metaclass=_SSLCertificateStatusEnumTypeWrapper):
    """A certificate status parameters."""

SSL_CERTIFICATE_STATUS_UNSPECIFIED: SSLCertificateStatus.ValueType  # 0
"""SSL certificate is unspecified."""
READY: SSLCertificateStatus.ValueType  # 1
"""SSL certificate is ready to use."""
CREATING: SSLCertificateStatus.ValueType  # 2
"""The option is deprecated. SSL certificate is creating."""
global___SSLCertificateStatus = SSLCertificateStatus

@typing.final
class SecondaryHostnames(google.protobuf.message.Message):
    """List of secondary (alternative) CNAMEs."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of secondary hostname values."""

    def __init__(
        self,
        *,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["values", b"values"]) -> None: ...

global___SecondaryHostnames = SecondaryHostnames

@typing.final
class Resource(google.protobuf.message.Message):
    """
    A CDN resource - representation of providers resource.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CNAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    SECONDARY_HOSTNAMES_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_NAME_FIELD_NUMBER: builtins.int
    ORIGIN_PROTOCOL_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PROVIDER_TYPE_FIELD_NUMBER: builtins.int
    PROVIDER_CNAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the resource."""
    folder_id: builtins.str
    """Folder id."""
    cname: builtins.str
    """CDN endpoint CNAME, must be unique among resources."""
    active: builtins.bool
    """Flag to create Resource either in active or disabled state.
    True - the content from CDN is available to clients.
    False - the content from CDN isn't available to clients.
    """
    origin_group_id: builtins.int
    """ID of the origin group."""
    origin_group_name: builtins.str
    """Name of the origin group."""
    origin_protocol: global___OriginProtocol.ValueType
    """Specify the protocol schema to be used in communication with origin."""
    provider_type: builtins.str
    """Type of the CDN provider for this resource."""
    provider_cname: builtins.str
    """CNAME provided by the CDN provider for this resource."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Update timestamp."""

    @property
    def options(self) -> global___ResourceOptions:
        """Resource settings and options to tune CDN edge behavior."""

    @property
    def secondary_hostnames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of secondary hostname strings."""

    @property
    def ssl_certificate(self) -> global___SSLCertificate:
        """SSL certificate options."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the resource."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cname: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        active: builtins.bool = ...,
        options: global___ResourceOptions | None = ...,
        secondary_hostnames: collections.abc.Iterable[builtins.str] | None = ...,
        origin_group_id: builtins.int = ...,
        origin_group_name: builtins.str = ...,
        origin_protocol: global___OriginProtocol.ValueType = ...,
        ssl_certificate: global___SSLCertificate | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        provider_type: builtins.str = ...,
        provider_cname: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "options", b"options", "ssl_certificate", b"ssl_certificate", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["active", b"active", "cname", b"cname", "created_at", b"created_at", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "options", b"options", "origin_group_id", b"origin_group_id", "origin_group_name", b"origin_group_name", "origin_protocol", b"origin_protocol", "provider_cname", b"provider_cname", "provider_type", b"provider_type", "secondary_hostnames", b"secondary_hostnames", "ssl_certificate", b"ssl_certificate", "updated_at", b"updated_at"]) -> None: ...

global___Resource = Resource

@typing.final
class ResourceOptions(google.protobuf.message.Message):
    """A major set of various resource options."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class BoolOption(google.protobuf.message.Message):
        """Set up bool values."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its [value] is applied to the resource.
        False - the option is disabled and its default value is used for the resource.
        """
        value: builtins.bool
        """Value of the option."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            value: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "value", b"value"]) -> None: ...

    @typing.final
    class StringOption(google.protobuf.message.Message):
        """A set of the string parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its [value] is applied to the resource.
        False - the option is disabled and its default value is used for the resource.
        """
        value: builtins.str
        """Value of the option."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "value", b"value"]) -> None: ...

    @typing.final
    class Int64Option(google.protobuf.message.Message):
        """A set of the numeric parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its [value] is applied to the resource.
        False - the option is disabled and its default value is used for the resource.
        """
        value: builtins.int
        """Value of the option."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "value", b"value"]) -> None: ...

    @typing.final
    class StringsListOption(google.protobuf.message.Message):
        """A set of the string list parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its [value] is applied to the resource.
        False - the option is disabled and its default value is used for the resource.
        """
        @property
        def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Value of the option."""

        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            value: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "value", b"value"]) -> None: ...

    @typing.final
    class StringsMapOption(google.protobuf.message.Message):
        """A set of the strings map parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class ValueEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

        ENABLED_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its [value] is applied to the resource.
        False - the option is disabled and its default value is used for the resource.
        """
        @property
        def value(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
            """Value of the option."""

        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            value: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "value", b"value"]) -> None: ...

    @typing.final
    class CachingTimes(google.protobuf.message.Message):
        """A set of the caching response time parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class CustomValuesEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.int
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.int = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

        SIMPLE_VALUE_FIELD_NUMBER: builtins.int
        CUSTOM_VALUES_FIELD_NUMBER: builtins.int
        simple_value: builtins.int
        """Caching time for a response with codes 200, 206, 301, 302.
        Responses with codes 4xx, 5xx will not be cached. Use `0s` disable to caching.
        Use [custom_values] field to specify a custom caching time for a response with specific codes.
        """
        @property
        def custom_values(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
            """Caching time for a response with specific codes. These settings have a higher priority than the value field.
            Response code (`304`, `404` for example). Use `any` to specify caching time for all response codes.
            Caching time in seconds (`0s`, `600s` for example). Use `0s` to disable caching for a specific response code.
            """

        def __init__(
            self,
            *,
            simple_value: builtins.int = ...,
            custom_values: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["custom_values", b"custom_values", "simple_value", b"simple_value"]) -> None: ...

    @typing.final
    class EdgeCacheSettings(google.protobuf.message.Message):
        """A set of the edge cache parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        DEFAULT_VALUE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its `values_variant` is applied to the resource.
        False - the option is disabled and its default value is used for the resource.
        """
        default_value: builtins.int
        """Content will be cached according to origin cache settings.
        The value applies for a response with codes 200, 201, 204, 206, 301, 302, 303, 304, 307, 308
        if an origin server does not have caching HTTP headers.
        Responses with other codes will not be cached.
        """
        @property
        def value(self) -> global___ResourceOptions.CachingTimes:
            """Value of the option."""

        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            value: global___ResourceOptions.CachingTimes | None = ...,
            default_value: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["default_value", b"default_value", "value", b"value", "values_variant", b"values_variant"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["default_value", b"default_value", "enabled", b"enabled", "value", b"value", "values_variant", b"values_variant"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["values_variant", b"values_variant"]) -> typing.Literal["value", "default_value"] | None: ...

    @typing.final
    class StringVariableMapOption(google.protobuf.message.Message):
        """A set of the string variable map parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class OneofString(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            VALUE_FIELD_NUMBER: builtins.int
            VALUES_FIELD_NUMBER: builtins.int
            @property
            def value(self) -> global___ResourceOptions.StringOption:
                """Using [StringOption] to set value."""

            @property
            def values(self) -> global___ResourceOptions.StringsListOption:
                """Using [StringsListOption] to set values."""

            def __init__(
                self,
                *,
                value: global___ResourceOptions.StringOption | None = ...,
                values: global___ResourceOptions.StringsListOption | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["string_option", b"string_option", "value", b"value", "values", b"values"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["string_option", b"string_option", "value", b"value", "values", b"values"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["string_option", b"string_option"]) -> typing.Literal["value", "values"] | None: ...

        @typing.final
        class ValueEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            @property
            def value(self) -> global___ResourceOptions.StringVariableMapOption.OneofString: ...
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: global___ResourceOptions.StringVariableMapOption.OneofString | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

        ENABLED_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its [value] is applied to the resource.
        False - the option is disabled and its default value is used for the resource.
        """
        @property
        def value(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___ResourceOptions.StringVariableMapOption.OneofString]:
            """Value of the option."""

        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            value: collections.abc.Mapping[builtins.str, global___ResourceOptions.StringVariableMapOption.OneofString] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "value", b"value"]) -> None: ...

    @typing.final
    class QueryParamsOptions(google.protobuf.message.Message):
        """A set of the query parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IGNORE_QUERY_STRING_FIELD_NUMBER: builtins.int
        QUERY_PARAMS_WHITELIST_FIELD_NUMBER: builtins.int
        QUERY_PARAMS_BLACKLIST_FIELD_NUMBER: builtins.int
        @property
        def ignore_query_string(self) -> global___ResourceOptions.BoolOption:
            """Using [BoolOption]. Selected by default. Files with different query parameters are cached as objects with the same key regardless of the parameter value."""

        @property
        def query_params_whitelist(self) -> global___ResourceOptions.StringsListOption:
            """Ignore All Except.
            Files with the specified query parameters are cached as objects with different keys,
            files with other parameters are cached as objects with the same key.
            """

        @property
        def query_params_blacklist(self) -> global___ResourceOptions.StringsListOption:
            """Ignore only. Files with the specified query parameters are cached as objects with the same key,
            files with other parameters are cached as objects with different keys.
            """

        def __init__(
            self,
            *,
            ignore_query_string: global___ResourceOptions.BoolOption | None = ...,
            query_params_whitelist: global___ResourceOptions.StringsListOption | None = ...,
            query_params_blacklist: global___ResourceOptions.StringsListOption | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["ignore_query_string", b"ignore_query_string", "query_params_blacklist", b"query_params_blacklist", "query_params_variant", b"query_params_variant", "query_params_whitelist", b"query_params_whitelist"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["ignore_query_string", b"ignore_query_string", "query_params_blacklist", b"query_params_blacklist", "query_params_variant", b"query_params_variant", "query_params_whitelist", b"query_params_whitelist"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["query_params_variant", b"query_params_variant"]) -> typing.Literal["ignore_query_string", "query_params_whitelist", "query_params_blacklist"] | None: ...

    @typing.final
    class RedirectOptions(google.protobuf.message.Message):
        """A set of the redirect parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REDIRECT_HTTP_TO_HTTPS_FIELD_NUMBER: builtins.int
        REDIRECT_HTTPS_TO_HTTP_FIELD_NUMBER: builtins.int
        @property
        def redirect_http_to_https(self) -> global___ResourceOptions.BoolOption:
            """Using [BoolOption]. Set up a redirect from HTTPS to HTTP."""

        @property
        def redirect_https_to_http(self) -> global___ResourceOptions.BoolOption:
            """Using [BoolOption]. Set up a redirect from HTTP to HTTPS."""

        def __init__(
            self,
            *,
            redirect_http_to_https: global___ResourceOptions.BoolOption | None = ...,
            redirect_https_to_http: global___ResourceOptions.BoolOption | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["redirect_http_to_https", b"redirect_http_to_https", "redirect_https_to_http", b"redirect_https_to_http", "redirect_variant", b"redirect_variant"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["redirect_http_to_https", b"redirect_http_to_https", "redirect_https_to_http", b"redirect_https_to_http", "redirect_variant", b"redirect_variant"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["redirect_variant", b"redirect_variant"]) -> typing.Literal["redirect_http_to_https", "redirect_https_to_http"] | None: ...

    @typing.final
    class HostOptions(google.protobuf.message.Message):
        """A set of the host parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HOST_FIELD_NUMBER: builtins.int
        FORWARD_HOST_HEADER_FIELD_NUMBER: builtins.int
        @property
        def host(self) -> global___ResourceOptions.StringOption:
            """Custom value for the Host header.

            Your server must be able to process requests with the chosen header.

            Default value (if [StringOption.enabled] is `false`) is [Resource.cname].
            """

        @property
        def forward_host_header(self) -> global___ResourceOptions.BoolOption:
            """Using [BoolOption]. Choose the Forward Host header option if is important to send in the request to the Origin
            the same Host header as was sent in the request to CDN server.
            """

        def __init__(
            self,
            *,
            host: global___ResourceOptions.StringOption | None = ...,
            forward_host_header: global___ResourceOptions.BoolOption | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["forward_host_header", b"forward_host_header", "host", b"host", "host_variant", b"host_variant"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["forward_host_header", b"forward_host_header", "host", b"host", "host_variant", b"host_variant"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["host_variant", b"host_variant"]) -> typing.Literal["host", "forward_host_header"] | None: ...

    @typing.final
    class CompressionOptions(google.protobuf.message.Message):
        """A set of the compression variant parameters."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FETCH_COMPRESSED_FIELD_NUMBER: builtins.int
        GZIP_ON_FIELD_NUMBER: builtins.int
        BROTLI_COMPRESSION_FIELD_NUMBER: builtins.int
        @property
        def fetch_compressed(self) -> global___ResourceOptions.BoolOption:
            """The Fetch compressed option helps you to reduce
            the bandwidth between origin and CDN servers.
            Also, content delivery speed becomes higher because of reducing the time
            for compressing files in a CDN.
            """

        @property
        def gzip_on(self) -> global___ResourceOptions.BoolOption:
            """Using [BoolOption]. GZip compression at CDN servers reduces file size by 70% and can be as high as 90%."""

        @property
        def brotli_compression(self) -> global___ResourceOptions.StringsListOption:
            """The option allows to compress content with brotli on the CDN's end.

            Compression is performed on the Origin Shielding. If a pre-cache server doesn't active for a resource, compression does not occur even if the option is enabled.

            Specify the content-type for each type of content you wish to have compressed. CDN servers will request only uncompressed content from the origin.
            """

        def __init__(
            self,
            *,
            fetch_compressed: global___ResourceOptions.BoolOption | None = ...,
            gzip_on: global___ResourceOptions.BoolOption | None = ...,
            brotli_compression: global___ResourceOptions.StringsListOption | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["brotli_compression", b"brotli_compression", "compression_variant", b"compression_variant", "fetch_compressed", b"fetch_compressed", "gzip_on", b"gzip_on"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["brotli_compression", b"brotli_compression", "compression_variant", b"compression_variant", "fetch_compressed", b"fetch_compressed", "gzip_on", b"gzip_on"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["compression_variant", b"compression_variant"]) -> typing.Literal["fetch_compressed", "gzip_on", "brotli_compression"] | None: ...

    @typing.final
    class RewriteOption(google.protobuf.message.Message):
        """An option for changing or redirecting query paths."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        BODY_FIELD_NUMBER: builtins.int
        FLAG_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its [flag] is applied to the resource.
        False - the option is disabled and its default value of the [flag] is used for the resource.
        """
        body: builtins.str
        """Pattern for rewrite.

        The value must have the following format: `<source path> <destination path>`, where both paths are regular expressions which use at least one group. E.g., `/foo/(.*) /bar/$1`.
        """
        flag: global___RewriteFlag.ValueType
        """Break flag is applied to the option by default.
        It is not shown in the field.
        """
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            body: builtins.str = ...,
            flag: global___RewriteFlag.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["body", b"body", "enabled", b"enabled", "flag", b"flag"]) -> None: ...

    @typing.final
    class SecureKeyOption(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        KEY_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its [flag] is applied to the resource.
        False - the option is disabled and its default value of the [flag] is used for the resource.
        """
        key: builtins.str
        """The key for the URL signing."""
        type: global___SecureKeyURLType.ValueType
        """The type of the URL signing. The URL could be available for all IP addresses or for the only one IP."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            key: builtins.str = ...,
            type: global___SecureKeyURLType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "key", b"key", "type", b"type"]) -> None: ...

    @typing.final
    class IPAddressACLOption(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        POLICY_TYPE_FIELD_NUMBER: builtins.int
        EXCEPTED_VALUES_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """True - the option is enabled and its [flag] is applied to the resource.
        False - the option is disabled and its default value of the [flag] is used for the resource.
        """
        policy_type: global___PolicyType.ValueType
        """The policy type. One of allow or deny value."""
        @property
        def excepted_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """The list of IP addresses to be allowed or denied."""

        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            policy_type: global___PolicyType.ValueType = ...,
            excepted_values: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "excepted_values", b"excepted_values", "policy_type", b"policy_type"]) -> None: ...

    DISABLE_CACHE_FIELD_NUMBER: builtins.int
    EDGE_CACHE_SETTINGS_FIELD_NUMBER: builtins.int
    BROWSER_CACHE_SETTINGS_FIELD_NUMBER: builtins.int
    CACHE_HTTP_HEADERS_FIELD_NUMBER: builtins.int
    QUERY_PARAMS_OPTIONS_FIELD_NUMBER: builtins.int
    SLICE_FIELD_NUMBER: builtins.int
    COMPRESSION_OPTIONS_FIELD_NUMBER: builtins.int
    REDIRECT_OPTIONS_FIELD_NUMBER: builtins.int
    HOST_OPTIONS_FIELD_NUMBER: builtins.int
    STATIC_HEADERS_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    STALE_FIELD_NUMBER: builtins.int
    ALLOWED_HTTP_METHODS_FIELD_NUMBER: builtins.int
    PROXY_CACHE_METHODS_SET_FIELD_NUMBER: builtins.int
    DISABLE_PROXY_FORCE_RANGES_FIELD_NUMBER: builtins.int
    STATIC_REQUEST_HEADERS_FIELD_NUMBER: builtins.int
    CUSTOM_SERVER_NAME_FIELD_NUMBER: builtins.int
    IGNORE_COOKIE_FIELD_NUMBER: builtins.int
    REWRITE_FIELD_NUMBER: builtins.int
    SECURE_KEY_FIELD_NUMBER: builtins.int
    IP_ADDRESS_ACL_FIELD_NUMBER: builtins.int
    @property
    def disable_cache(self) -> global___ResourceOptions.BoolOption:
        """Set up a cache status."""

    @property
    def edge_cache_settings(self) -> global___ResourceOptions.EdgeCacheSettings:
        """Set up [EdgeCacheSettings]."""

    @property
    def browser_cache_settings(self) -> global___ResourceOptions.Int64Option:
        """Using [Int64Option]. Set up a cache period for the end-users browser.
        Content will be cached due to origin settings.
        If there are no cache settings on your origin, the content will not be cached.
        The list of HTTP response codes that can be cached in browsers: 200, 201, 204, 206, 301, 302, 303, 304, 307, 308.
        Other response codes will not be cached.
        The default value is 4 days.
        """

    @property
    def cache_http_headers(self) -> global___ResourceOptions.StringsListOption:
        """List HTTP headers that must be included in responses to clients."""

    @property
    def query_params_options(self) -> global___ResourceOptions.QueryParamsOptions:
        """Set up [QueryParamsOptions]."""

    @property
    def slice(self) -> global___ResourceOptions.BoolOption:
        """Files larger than 10 MB will be requested and cached in parts (no larger than 10 MB each part). It reduces time to first byte.

        The origin must support HTTP Range requests.

        By default the option is disabled.
        """

    @property
    def compression_options(self) -> global___ResourceOptions.CompressionOptions:
        """Set up compression variant."""

    @property
    def redirect_options(self) -> global___ResourceOptions.RedirectOptions:
        """Set up redirects."""

    @property
    def host_options(self) -> global___ResourceOptions.HostOptions:
        """Set up host parameters."""

    @property
    def static_headers(self) -> global___ResourceOptions.StringsMapOption:
        """Set up static headers that CDN servers send in responses to clients."""

    @property
    def cors(self) -> global___ResourceOptions.StringsListOption:
        """Parameter that lets browsers get access to selected resources from a domain
        different to a domain from which the request is received.
        [Read more](/docs/cdn/concepts/cors).
        """

    @property
    def stale(self) -> global___ResourceOptions.StringsListOption:
        """List of errors which instruct CDN servers to serve stale content to clients.

        Possible values: `error`, `http_403`, `http_404`, `http_429`, `http_500`, `http_502`, `http_503`, `http_504`, `invalid_header`, `timeout`, `updating`.
        """

    @property
    def allowed_http_methods(self) -> global___ResourceOptions.StringsListOption:
        """HTTP methods for your CDN content. By default the following methods
        are allowed: GET, HEAD, POST, PUT, PATCH, DELETE, OPTIONS.
        In case some methods are not allowed to the user, they will get the 405
        (Method Not Allowed) response. If the method is not supported,
        the user gets the 501 (Not Implemented) response.
        """

    @property
    def proxy_cache_methods_set(self) -> global___ResourceOptions.BoolOption:
        """Allows caching for GET, HEAD and POST requests."""

    @property
    def disable_proxy_force_ranges(self) -> global___ResourceOptions.BoolOption:
        """Disabling proxy force ranges."""

    @property
    def static_request_headers(self) -> global___ResourceOptions.StringsMapOption:
        """Set up custom headers that CDN servers send in requests to origins.
        The Header name field can contain letters (A-Z, a-z), numbers (0-9), dashes (-) and underscores (_).
        The Value field can contain letters (A-Z, a-z), numbers (0-9), dashes (-),
        underscores (_), slashes (/), colons (:), equal (=), dots (.), and spaces.
        """

    @property
    def custom_server_name(self) -> global___ResourceOptions.StringOption:
        """Wildcard additional CNAME.
        If a resource has a wildcard additional CNAME, you can use your own certificate for content delivery via HTTPS. Read-only.
        """

    @property
    def ignore_cookie(self) -> global___ResourceOptions.BoolOption:
        """Using [BoolOption] for ignoring cookie."""

    @property
    def rewrite(self) -> global___ResourceOptions.RewriteOption:
        """Changing or redirecting query paths."""

    @property
    def secure_key(self) -> global___ResourceOptions.SecureKeyOption:
        """Secure token to protect contect and limit access by IP addresses and time limits."""

    @property
    def ip_address_acl(self) -> global___ResourceOptions.IPAddressACLOption:
        """Manage the state of the IP access policy option.
        The option controls access to content from the specified IP addresses.
        """

    def __init__(
        self,
        *,
        disable_cache: global___ResourceOptions.BoolOption | None = ...,
        edge_cache_settings: global___ResourceOptions.EdgeCacheSettings | None = ...,
        browser_cache_settings: global___ResourceOptions.Int64Option | None = ...,
        cache_http_headers: global___ResourceOptions.StringsListOption | None = ...,
        query_params_options: global___ResourceOptions.QueryParamsOptions | None = ...,
        slice: global___ResourceOptions.BoolOption | None = ...,
        compression_options: global___ResourceOptions.CompressionOptions | None = ...,
        redirect_options: global___ResourceOptions.RedirectOptions | None = ...,
        host_options: global___ResourceOptions.HostOptions | None = ...,
        static_headers: global___ResourceOptions.StringsMapOption | None = ...,
        cors: global___ResourceOptions.StringsListOption | None = ...,
        stale: global___ResourceOptions.StringsListOption | None = ...,
        allowed_http_methods: global___ResourceOptions.StringsListOption | None = ...,
        proxy_cache_methods_set: global___ResourceOptions.BoolOption | None = ...,
        disable_proxy_force_ranges: global___ResourceOptions.BoolOption | None = ...,
        static_request_headers: global___ResourceOptions.StringsMapOption | None = ...,
        custom_server_name: global___ResourceOptions.StringOption | None = ...,
        ignore_cookie: global___ResourceOptions.BoolOption | None = ...,
        rewrite: global___ResourceOptions.RewriteOption | None = ...,
        secure_key: global___ResourceOptions.SecureKeyOption | None = ...,
        ip_address_acl: global___ResourceOptions.IPAddressACLOption | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allowed_http_methods", b"allowed_http_methods", "browser_cache_settings", b"browser_cache_settings", "cache_http_headers", b"cache_http_headers", "compression_options", b"compression_options", "cors", b"cors", "custom_server_name", b"custom_server_name", "disable_cache", b"disable_cache", "disable_proxy_force_ranges", b"disable_proxy_force_ranges", "edge_cache_settings", b"edge_cache_settings", "host_options", b"host_options", "ignore_cookie", b"ignore_cookie", "ip_address_acl", b"ip_address_acl", "proxy_cache_methods_set", b"proxy_cache_methods_set", "query_params_options", b"query_params_options", "redirect_options", b"redirect_options", "rewrite", b"rewrite", "secure_key", b"secure_key", "slice", b"slice", "stale", b"stale", "static_headers", b"static_headers", "static_request_headers", b"static_request_headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allowed_http_methods", b"allowed_http_methods", "browser_cache_settings", b"browser_cache_settings", "cache_http_headers", b"cache_http_headers", "compression_options", b"compression_options", "cors", b"cors", "custom_server_name", b"custom_server_name", "disable_cache", b"disable_cache", "disable_proxy_force_ranges", b"disable_proxy_force_ranges", "edge_cache_settings", b"edge_cache_settings", "host_options", b"host_options", "ignore_cookie", b"ignore_cookie", "ip_address_acl", b"ip_address_acl", "proxy_cache_methods_set", b"proxy_cache_methods_set", "query_params_options", b"query_params_options", "redirect_options", b"redirect_options", "rewrite", b"rewrite", "secure_key", b"secure_key", "slice", b"slice", "stale", b"stale", "static_headers", b"static_headers", "static_request_headers", b"static_request_headers"]) -> None: ...

global___ResourceOptions = ResourceOptions

@typing.final
class SSLTargetCertificate(google.protobuf.message.Message):
    """A set of the personal SSL certificate parameters."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    type: global___SSLCertificateType.ValueType
    """Type of the certificate."""
    @property
    def data(self) -> global___SSLCertificateData:
        """Certificate data."""

    def __init__(
        self,
        *,
        type: global___SSLCertificateType.ValueType = ...,
        data: global___SSLCertificateData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "type", b"type"]) -> None: ...

global___SSLTargetCertificate = SSLTargetCertificate

@typing.final
class SSLCertificate(google.protobuf.message.Message):
    """A SSL certificate parameters."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    type: global___SSLCertificateType.ValueType
    """Type of the certificate."""
    status: global___SSLCertificateStatus.ValueType
    """Active status."""
    @property
    def data(self) -> global___SSLCertificateData:
        """Certificate data."""

    def __init__(
        self,
        *,
        type: global___SSLCertificateType.ValueType = ...,
        status: global___SSLCertificateStatus.ValueType = ...,
        data: global___SSLCertificateData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "status", b"status", "type", b"type"]) -> None: ...

global___SSLCertificate = SSLCertificate

@typing.final
class SSLCertificateData(google.protobuf.message.Message):
    """A certificate data parameters."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CM_FIELD_NUMBER: builtins.int
    @property
    def cm(self) -> global___SSLCertificateCMData:
        """Custom (add your SSL certificate by uploading the certificate
        in PEM format and your private key).
        """

    def __init__(
        self,
        *,
        cm: global___SSLCertificateCMData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cm", b"cm", "ssl_certificate_data_variant", b"ssl_certificate_data_variant"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cm", b"cm", "ssl_certificate_data_variant", b"ssl_certificate_data_variant"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ssl_certificate_data_variant", b"ssl_certificate_data_variant"]) -> typing.Literal["cm"] | None: ...

global___SSLCertificateData = SSLCertificateData

@typing.final
class SSLCertificateCMData(google.protobuf.message.Message):
    """A certificate data custom parameters."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the custom certificate."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___SSLCertificateCMData = SSLCertificateCMData



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/pxf.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/pxf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/mdb/greenplum/v1/pxf.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xbd\x04\n\tPXFConfig\x12\x42\n\x12\x63onnection_timeout\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12>\n\x0eupload_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12<\n\x0bmax_threads\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x42\n\x1epool_allow_core_thread_timeout\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0epool_core_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x41\n\x13pool_queue_capacity\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\rpool_max_size\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x32\n\x03xmx\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=64\x12\x32\n\x03xms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=64\"\xd9\x01\n\x0cPXFConfigSet\x12H\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfigB\x04\xe8\xc7\x31\x01\x12=\n\x0buser_config\x18\x02 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfig\x12@\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfig\"\xe1\x01\n\x0fPXFDatasourceS3\x12\x1d\n\naccess_key\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x1d\n\nsecret_key\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12/\n\x0b\x66\x61st_upload\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12_\n\x08\x65ndpoint\x18\x04 \x01(\tBM\xf2\xc7\x31@(((s3|https?)://)?([a-z0-9]([a-z0-9-]*[a-z0-9])?[.])+[a-z]{2,})?\x8a\xc8\x31\x05<=200\"\xa8\x05\n\x11PXFDatasourceJDBC\x12\x18\n\x06\x64river\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x17\n\x03url\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x17\n\x04user\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x1b\n\x08password\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x46\n\x14statement_batch_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35\x30-1000\x12G\n\x14statement_fetch_size\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x35\x30-10000\x12I\n\x17statement_query_timeout\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35-43200\x12\x30\n\x0cpool_enabled\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x11pool_maximum_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-200\x12M\n\x17pool_connection_timeout\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0f\xfa\xc7\x31\x0b\x35\x30\x30\x30-600000\x12G\n\x11pool_idle_timeout\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0f\xfa\xc7\x31\x0b\x35\x30\x30\x30-600000\x12\x41\n\x11pool_minimum_idle\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-200\"^\n\x11PXFDatasourceCore\x12\x1d\n\ndefault_fs\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12*\n\x16security_auth_to_local\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xcf\x02\n\x15PXFDatasourceKerberos\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1a\n\x07primary\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x19\n\x05realm\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\'\n\x0bkdc_servers\x18\x04 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12\x1f\n\x0c\x61\x64min_server\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12!\n\x0e\x64\x65\x66\x61ult_domain\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x66\n\rkeytab_base64\x18\x07 \x01(\tBO\xf2\xc7\x31@^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$\x8a\xc8\x31\x07<=65536\"\xad\x01\n\x1cPXFDatasourceHDFSDfsNamenode\x12\x1f\n\x0brpc_address\x18\x01 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\'\n\x13service_rpc_address\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12 \n\x0chttp_address\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12!\n\rhttps_address\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xbd\x03\n\x14PXFDatasourceHDFSDfs\x12\x41\n\x1dha_automatic_failover_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x1a\x62lock_access_token_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15use_datanode_hostname\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x62\n\tnamenodes\x18\x04 \x03(\x0b\x32\x42.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSDfs.NamenodesEntryB\x0b\x82\xc8\x31\x07<=10000\x12\x14\n\x0cnameservices\x18\x05 \x01(\t\x1am\n\x0eNamenodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12J\n\x05value\x18\x02 \x01(\x0b\x32;.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSDfsNamenode:\x02\x38\x01\"\x96\x02\n\x19PXFDatasourceHDFSYarnHaRm\x12\x1f\n\x17resourcemanager_address\x18\x01 \x01(\t\x12)\n!resourcemanager_scheduler_address\x18\x02 \x01(\t\x12\x30\n(resourcemanager_resource_tracker_address\x18\x03 \x01(\t\x12%\n\x1dresourcemanager_admin_address\x18\x04 \x01(\t\x12&\n\x1eresourcemanager_webapp_address\x18\x05 \x01(\t\x12,\n$resourcemanager_webapp_https_address\x18\x06 \x01(\t\"\xe7\x03\n\x15PXFDatasourceHDFSYarn\x12>\n\x1aresourcemanager_ha_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n(resourcemanager_ha_auto_failover_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n)resourcemanager_ha_auto_failover_embedded\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\x1aresourcemanager_cluster_id\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12Z\n\x05ha_rm\x18\x05 \x03(\x0b\x32>.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSYarn.HaRmEntryB\x0b\x82\xc8\x31\x07<=10000\x1a\x65\n\tHaRmEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSYarnHaRm:\x02\x38\x01\"\xe4\x03\n\x11PXFDatasourceHDFS\x12>\n\x04\x63ore\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceCore\x12\x46\n\x08kerberos\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.PXFDatasourceKerberos\x12\x36\n\x12user_impersonation\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x08username\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x46\n\x17sasl_connection_retries\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-50\x12$\n\x08zk_hosts\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12@\n\x03\x64\x66s\x18\x07 \x01(\x0b\x32\x33.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSDfs\x12\x42\n\x04yarn\x18\x08 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSYarn\"\x92\x04\n\x11PXFDatasourceHive\x12>\n\x04\x63ore\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceCore\x12\x46\n\x08kerberos\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.PXFDatasourceKerberos\x12\x36\n\x12user_impersonation\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x08username\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x46\n\x17sasl_connection_retries\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-50\x12$\n\x08zk_hosts\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12\'\n\x03ppd\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x0emetastore_uris\x18\x08 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12\x30\n\x1cmetastore_kerberos_principal\x18\t \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12+\n\x17\x61uth_kerberos_principal\x18\n \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xd2\x02\n\rPXFDatasource\x12\x31\n\x04name\x18\x01 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\x12<\n\x02s3\x18\x02 \x01(\x0b\x32..yandex.cloud.mdb.greenplum.v1.PXFDatasourceS3H\x00\x12@\n\x04jdbc\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceJDBCH\x00\x12@\n\x04hdfs\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSH\x00\x12@\n\x04hive\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHiveH\x00\x42\n\n\x08settingsBp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.pxf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_PXFCONFIG'].fields_by_name['connection_timeout']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['connection_timeout']._serialized_options = b'\372\3071\0055-600'
  _globals['_PXFCONFIG'].fields_by_name['upload_timeout']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['upload_timeout']._serialized_options = b'\372\3071\0055-600'
  _globals['_PXFCONFIG'].fields_by_name['max_threads']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['max_threads']._serialized_options = b'\372\3071\0061-1024'
  _globals['_PXFCONFIG'].fields_by_name['pool_core_size']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['pool_core_size']._serialized_options = b'\372\3071\0061-1024'
  _globals['_PXFCONFIG'].fields_by_name['pool_queue_capacity']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['pool_queue_capacity']._serialized_options = b'\372\3071\003>=0'
  _globals['_PXFCONFIG'].fields_by_name['pool_max_size']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['pool_max_size']._serialized_options = b'\372\3071\0061-1024'
  _globals['_PXFCONFIG'].fields_by_name['xmx']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['xmx']._serialized_options = b'\372\3071\004>=64'
  _globals['_PXFCONFIG'].fields_by_name['xms']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['xms']._serialized_options = b'\372\3071\004>=64'
  _globals['_PXFCONFIGSET'].fields_by_name['effective_config']._loaded_options = None
  _globals['_PXFCONFIGSET'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_PXFDATASOURCES3'].fields_by_name['access_key']._loaded_options = None
  _globals['_PXFDATASOURCES3'].fields_by_name['access_key']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCES3'].fields_by_name['secret_key']._loaded_options = None
  _globals['_PXFDATASOURCES3'].fields_by_name['secret_key']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCES3'].fields_by_name['endpoint']._loaded_options = None
  _globals['_PXFDATASOURCES3'].fields_by_name['endpoint']._serialized_options = b'\362\3071@(((s3|https?)://)?([a-z0-9]([a-z0-9-]*[a-z0-9])?[.])+[a-z]{2,})?\212\3101\005<=200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['driver']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['driver']._serialized_options = b'\212\3101\004<=50'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['url']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['url']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['user']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['user']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['password']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['password']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_batch_size']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_batch_size']._serialized_options = b'\372\3071\00750-1000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_fetch_size']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_fetch_size']._serialized_options = b'\372\3071\01050-10000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_query_timeout']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_query_timeout']._serialized_options = b'\372\3071\0075-43200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_maximum_size']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_maximum_size']._serialized_options = b'\372\3071\0051-200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_connection_timeout']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_connection_timeout']._serialized_options = b'\372\3071\0135000-600000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_idle_timeout']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_idle_timeout']._serialized_options = b'\372\3071\0135000-600000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_minimum_idle']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_minimum_idle']._serialized_options = b'\372\3071\0050-200'
  _globals['_PXFDATASOURCECORE'].fields_by_name['default_fs']._loaded_options = None
  _globals['_PXFDATASOURCECORE'].fields_by_name['default_fs']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCECORE'].fields_by_name['security_auth_to_local']._loaded_options = None
  _globals['_PXFDATASOURCECORE'].fields_by_name['security_auth_to_local']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['primary']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['primary']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['realm']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['realm']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['kdc_servers']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['kdc_servers']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['admin_server']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['admin_server']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['default_domain']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['default_domain']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['keytab_base64']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['keytab_base64']._serialized_options = b'\362\3071@^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$\212\3101\007<=65536'
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['rpc_address']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['rpc_address']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['service_rpc_address']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['service_rpc_address']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['http_address']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['http_address']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['https_address']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['https_address']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._serialized_options = b'8\001'
  _globals['_PXFDATASOURCEHDFSDFS'].fields_by_name['namenodes']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFS'].fields_by_name['namenodes']._serialized_options = b'\202\3101\007<=10000'
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._serialized_options = b'8\001'
  _globals['_PXFDATASOURCEHDFSYARN'].fields_by_name['resourcemanager_cluster_id']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSYARN'].fields_by_name['resourcemanager_cluster_id']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSYARN'].fields_by_name['ha_rm']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSYARN'].fields_by_name['ha_rm']._serialized_options = b'\202\3101\007<=10000'
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['username']._loaded_options = None
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['username']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['sasl_connection_retries']._loaded_options = None
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['sasl_connection_retries']._serialized_options = b'\372\3071\0041-50'
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['zk_hosts']._loaded_options = None
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['zk_hosts']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['username']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['username']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['sasl_connection_retries']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['sasl_connection_retries']._serialized_options = b'\372\3071\0041-50'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['zk_hosts']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['zk_hosts']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['metastore_uris']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['metastore_uris']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['metastore_kerberos_principal']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['metastore_kerberos_principal']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['auth_kerberos_principal']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['auth_kerberos_principal']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCE'].fields_by_name['name']._loaded_options = None
  _globals['_PXFDATASOURCE'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_PXFCONFIG']._serialized_start=138
  _globals['_PXFCONFIG']._serialized_end=711
  _globals['_PXFCONFIGSET']._serialized_start=714
  _globals['_PXFCONFIGSET']._serialized_end=931
  _globals['_PXFDATASOURCES3']._serialized_start=934
  _globals['_PXFDATASOURCES3']._serialized_end=1159
  _globals['_PXFDATASOURCEJDBC']._serialized_start=1162
  _globals['_PXFDATASOURCEJDBC']._serialized_end=1842
  _globals['_PXFDATASOURCECORE']._serialized_start=1844
  _globals['_PXFDATASOURCECORE']._serialized_end=1938
  _globals['_PXFDATASOURCEKERBEROS']._serialized_start=1941
  _globals['_PXFDATASOURCEKERBEROS']._serialized_end=2276
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE']._serialized_start=2279
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE']._serialized_end=2452
  _globals['_PXFDATASOURCEHDFSDFS']._serialized_start=2455
  _globals['_PXFDATASOURCEHDFSDFS']._serialized_end=2900
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._serialized_start=2791
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._serialized_end=2900
  _globals['_PXFDATASOURCEHDFSYARNHARM']._serialized_start=2903
  _globals['_PXFDATASOURCEHDFSYARNHARM']._serialized_end=3181
  _globals['_PXFDATASOURCEHDFSYARN']._serialized_start=3184
  _globals['_PXFDATASOURCEHDFSYARN']._serialized_end=3671
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._serialized_start=3570
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._serialized_end=3671
  _globals['_PXFDATASOURCEHDFS']._serialized_start=3674
  _globals['_PXFDATASOURCEHDFS']._serialized_end=4158
  _globals['_PXFDATASOURCEHIVE']._serialized_start=4161
  _globals['_PXFDATASOURCEHIVE']._serialized_end=4691
  _globals['_PXFDATASOURCE']._serialized_start=4694
  _globals['_PXFDATASOURCE']._serialized_end=5032
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Key(google.protobuf.message.Message):
    """A Key resource. For more information, see [Authorized keys](/docs/iam/concepts/authorization/key)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Algorithm:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AlgorithmEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Key._Algorithm.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ALGORITHM_UNSPECIFIED: Key._Algorithm.ValueType  # 0
        RSA_2048: Key._Algorithm.ValueType  # 1
        """RSA with a 2048-bit key size. Default value."""
        RSA_4096: Key._Algorithm.ValueType  # 2
        """RSA with a 4096-bit key size."""

    class Algorithm(_Algorithm, metaclass=_AlgorithmEnumTypeWrapper): ...
    ALGORITHM_UNSPECIFIED: Key.Algorithm.ValueType  # 0
    RSA_2048: Key.Algorithm.ValueType  # 1
    """RSA with a 2048-bit key size. Default value."""
    RSA_4096: Key.Algorithm.ValueType  # 2
    """RSA with a 4096-bit key size."""

    ID_FIELD_NUMBER: builtins.int
    USER_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    KEY_ALGORITHM_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    LAST_USED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Key resource."""
    user_account_id: builtins.str
    """ID of the user account that the Key resource belongs to."""
    service_account_id: builtins.str
    """ID of the service account that the Key resource belongs to."""
    description: builtins.str
    """Description of the Key resource. 0-256 characters long."""
    key_algorithm: global___Key.Algorithm.ValueType
    """An algorithm used to generate a key pair of the Key resource."""
    public_key: builtins.str
    """A public key of the Key resource."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def last_used_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp for the last use of this key."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        user_account_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        description: builtins.str = ...,
        key_algorithm: global___Key.Algorithm.ValueType = ...,
        public_key: builtins.str = ...,
        last_used_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "last_used_at", b"last_used_at", "service_account_id", b"service_account_id", "subject", b"subject", "user_account_id", b"user_account_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "id", b"id", "key_algorithm", b"key_algorithm", "last_used_at", b"last_used_at", "public_key", b"public_key", "service_account_id", b"service_account_id", "subject", b"subject", "user_account_id", b"user_account_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["subject", b"subject"]) -> typing.Literal["user_account_id", "service_account_id"] | None: ...

global___Key = Key



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v1/project_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v1/project_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.datasphere.v1 import project_pb2 as yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/datasphere/v1/project_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a(yandex/cloud/datasphere/v1/project.proto\"\x8e\x02\n\x14\x43reateProjectRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x39\n\x04name\x18\x02 \x01(\tB+\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x08settings\x18\x04 \x01(\x0b\x32,.yandex.cloud.datasphere.v1.Project.Settings\x12:\n\x06limits\x18\x05 \x01(\x0b\x32*.yandex.cloud.datasphere.v1.Project.Limits\"+\n\x15\x43reateProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\xc1\x02\n\x14UpdateProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x39\n\x04name\x18\x03 \x01(\tB+\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x08settings\x18\x05 \x01(\x0b\x32,.yandex.cloud.datasphere.v1.Project.Settings\x12:\n\x06limits\x18\x06 \x01(\x0b\x32*.yandex.cloud.datasphere.v1.Project.Limits\"+\n\x15UpdateProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"9\n\x14\x44\x65leteProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\"+\n\x15\x44\x65leteProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"7\n\x12OpenProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\")\n\x13OpenProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"A\n\x13OpenProjectResponse\x12\x13\n\x0bproject_url\x18\x01 \x01(\t\x12\x15\n\rsession_token\x18\x02 \x01(\t\"6\n\x11GetProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\"t\n\x13ListProjectsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"f\n\x14ListProjectsResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.yandex.cloud.datasphere.v1.Project\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x15GetUnitBalanceRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\"K\n\x16GetUnitBalanceResponse\x12\x31\n\x0cunit_balance\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"m\n\x15SetUnitBalanceRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\x31\n\x0cunit_balance\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xdd\x01\n\x17ProjectExecutionRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12 \n\x0bnotebook_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x1c\n\x07\x63\x65ll_id\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x30\n\x0finput_variables\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1d\n\x15output_variable_names\x18\x05 \x03(\tB\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"~\n\x18ProjectExecutionMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12 \n\x0bnotebook_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x1c\n\x07\x63\x65ll_id\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x42\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"&\n\x18ProjectExecutionResponseJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\x32\xa5\x0c\n\x0eProjectService\x12\xa5\x01\n\x06\x43reate\x12\x30.yandex.cloud.datasphere.v1.CreateProjectRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2* \n\x15\x43reateProjectMetadata\x12\x07Project\x82\xd3\xe4\x93\x02\x1c\"\x17/datasphere/v1/projects:\x01*\x12\xb2\x01\n\x06Update\x12\x30.yandex.cloud.datasphere.v1.UpdateProjectRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2* \n\x15UpdateProjectMetadata\x12\x07Project\x82\xd3\xe4\x93\x02)2$/datasphere/v1/projects/{project_id}:\x01*\x12\xbd\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.datasphere.v1.DeleteProjectRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*.\n\x15\x44\x65leteProjectMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/datasphere/v1/projects/{project_id}\x12\xba\x01\n\x04Open\x12..yandex.cloud.datasphere.v1.OpenProjectRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2**\n\x13OpenProjectMetadata\x12\x13OpenProjectResponse\x82\xd3\xe4\x93\x02+\")/datasphere/v1/projects/{project_id}:open\x12\x87\x01\n\x03Get\x12-.yandex.cloud.datasphere.v1.GetProjectRequest\x1a#.yandex.cloud.datasphere.v1.Project\",\x82\xd3\xe4\x93\x02&\x12$/datasphere/v1/projects/{project_id}\x12\x8a\x01\n\x04List\x12/.yandex.cloud.datasphere.v1.ListProjectsRequest\x1a\x30.yandex.cloud.datasphere.v1.ListProjectsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/datasphere/v1/projects\x12\xb1\x01\n\x0eGetUnitBalance\x12\x31.yandex.cloud.datasphere.v1.GetUnitBalanceRequest\x1a\x32.yandex.cloud.datasphere.v1.GetUnitBalanceResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/datasphere/v1/projects/{project_id}:unitBalance\x12\x98\x01\n\x0eSetUnitBalance\x12\x31.yandex.cloud.datasphere.v1.SetUnitBalanceRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35\"0/datasphere/v1/projects/{project_id}:unitBalance:\x01*\x12\xd2\x01\n\x07\x45xecute\x12\x33.yandex.cloud.datasphere.v1.ProjectExecutionRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*4\n\x18ProjectExecutionMetadata\x12\x18ProjectExecutionResponse\x82\xd3\xe4\x93\x02\x31\",/datasphere/v1/projects/{project_id}:execute:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.project_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\004<=63'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\004<=63'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_OPENPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_OPENPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_GETUNITBALANCEREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETUNITBALANCEREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_SETUNITBALANCEREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_SETUNITBALANCEREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONREQUEST'].oneofs_by_name['target']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['notebook_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['notebook_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['cell_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['cell_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONMETADATA'].oneofs_by_name['target']._loaded_options = None
  _globals['_PROJECTEXECUTIONMETADATA'].oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['notebook_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['notebook_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['cell_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['cell_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateProjectMetadata\022\007Project\202\323\344\223\002\034\"\027/datasphere/v1/projects:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateProjectMetadata\022\007Project\202\323\344\223\002)2$/datasphere/v1/projects/{project_id}:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteProjectMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/datasphere/v1/projects/{project_id}'
  _globals['_PROJECTSERVICE'].methods_by_name['Open']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Open']._serialized_options = b'\262\322**\n\023OpenProjectMetadata\022\023OpenProjectResponse\202\323\344\223\002+\")/datasphere/v1/projects/{project_id}:open'
  _globals['_PROJECTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/datasphere/v1/projects/{project_id}'
  _globals['_PROJECTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/datasphere/v1/projects'
  _globals['_PROJECTSERVICE'].methods_by_name['GetUnitBalance']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['GetUnitBalance']._serialized_options = b'\202\323\344\223\0022\0220/datasphere/v1/projects/{project_id}:unitBalance'
  _globals['_PROJECTSERVICE'].methods_by_name['SetUnitBalance']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['SetUnitBalance']._serialized_options = b'\202\323\344\223\0025\"0/datasphere/v1/projects/{project_id}:unitBalance:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Execute']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Execute']._serialized_options = b'\262\322*4\n\030ProjectExecutionMetadata\022\030ProjectExecutionResponse\202\323\344\223\0021\",/datasphere/v1/projects/{project_id}:execute:\001*'
  _globals['_CREATEPROJECTREQUEST']._serialized_start=383
  _globals['_CREATEPROJECTREQUEST']._serialized_end=653
  _globals['_CREATEPROJECTMETADATA']._serialized_start=655
  _globals['_CREATEPROJECTMETADATA']._serialized_end=698
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=701
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=1022
  _globals['_UPDATEPROJECTMETADATA']._serialized_start=1024
  _globals['_UPDATEPROJECTMETADATA']._serialized_end=1067
  _globals['_DELETEPROJECTREQUEST']._serialized_start=1069
  _globals['_DELETEPROJECTREQUEST']._serialized_end=1126
  _globals['_DELETEPROJECTMETADATA']._serialized_start=1128
  _globals['_DELETEPROJECTMETADATA']._serialized_end=1171
  _globals['_OPENPROJECTREQUEST']._serialized_start=1173
  _globals['_OPENPROJECTREQUEST']._serialized_end=1228
  _globals['_OPENPROJECTMETADATA']._serialized_start=1230
  _globals['_OPENPROJECTMETADATA']._serialized_end=1271
  _globals['_OPENPROJECTRESPONSE']._serialized_start=1273
  _globals['_OPENPROJECTRESPONSE']._serialized_end=1338
  _globals['_GETPROJECTREQUEST']._serialized_start=1340
  _globals['_GETPROJECTREQUEST']._serialized_end=1394
  _globals['_LISTPROJECTSREQUEST']._serialized_start=1396
  _globals['_LISTPROJECTSREQUEST']._serialized_end=1512
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=1514
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=1616
  _globals['_GETUNITBALANCEREQUEST']._serialized_start=1618
  _globals['_GETUNITBALANCEREQUEST']._serialized_end=1676
  _globals['_GETUNITBALANCERESPONSE']._serialized_start=1678
  _globals['_GETUNITBALANCERESPONSE']._serialized_end=1753
  _globals['_SETUNITBALANCEREQUEST']._serialized_start=1755
  _globals['_SETUNITBALANCEREQUEST']._serialized_end=1864
  _globals['_PROJECTEXECUTIONREQUEST']._serialized_start=1867
  _globals['_PROJECTEXECUTIONREQUEST']._serialized_end=2088
  _globals['_PROJECTEXECUTIONMETADATA']._serialized_start=2090
  _globals['_PROJECTEXECUTIONMETADATA']._serialized_end=2216
  _globals['_PROJECTEXECUTIONRESPONSE']._serialized_start=2218
  _globals['_PROJECTEXECUTIONRESPONSE']._serialized_end=2256
  _globals['_PROJECTSERVICE']._serialized_start=2259
  _globals['_PROJECTSERVICE']._serialized_end=3832
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/rule_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/rule_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import resource_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2
from yandex.cloud.cdn.v1 import rule_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_rule__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/cdn/v1/rule_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/cdn/v1/resource.proto\x1a\x1eyandex/cloud/cdn/v1/rule.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"=\n\x18ListResourceRulesRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"E\n\x19ListResourceRulesResponse\x12(\n\x05rules\x18\x01 \x03(\x0b\x32\x19.yandex.cloud.cdn.v1.Rule\"\xb6\x01\n\x19\x43reateResourceRuleRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\x0crule_pattern\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\x35\n\x07options\x18\x04 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\"X\n\x1a\x43reateResourceRuleMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"T\n\x16GetResourceRuleRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"\xc7\x01\n\x19UpdateResourceRuleRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x16\n\x04name\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\x0crule_pattern\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x35\n\x07options\x18\x05 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\"X\n\x1aUpdateResourceRuleMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"W\n\x19\x44\x65leteResourceRuleRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"X\n\x1a\x44\x65leteResourceRuleMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>02\x80\x06\n\x14ResourceRulesService\x12|\n\x04List\x12-.yandex.cloud.cdn.v1.ListResourceRulesRequest\x1a..yandex.cloud.cdn.v1.ListResourceRulesResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/cdn/v1/rules\x12\x9b\x01\n\x06\x43reate\x12..yandex.cloud.cdn.v1.CreateResourceRuleRequest\x1a!.yandex.cloud.operation.Operation\">\xb2\xd2*\"\n\x1a\x43reateResourceRuleMetadata\x12\x04Rule\x82\xd3\xe4\x93\x02\x12\"\r/cdn/v1/rules:\x01*\x12n\n\x03Get\x12+.yandex.cloud.cdn.v1.GetResourceRuleRequest\x1a\x19.yandex.cloud.cdn.v1.Rule\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/cdn/v1/rules/{rule_id}\x12\xa5\x01\n\x06Update\x12..yandex.cloud.cdn.v1.UpdateResourceRuleRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*\"\n\x1aUpdateResourceRuleMetadata\x12\x04Rule\x82\xd3\xe4\x93\x02\x1c\x32\x17/cdn/v1/rules/{rule_id}:\x01*\x12\xb3\x01\n\x06\x44\x65lete\x12..yandex.cloud.cdn.v1.DeleteResourceRuleRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*3\n\x1a\x44\x65leteResourceRuleMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x19*\x17/cdn/v1/rules/{rule_id}BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.rule_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_LISTRESOURCERULESREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_LISTRESOURCERULESREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['rule_pattern']._loaded_options = None
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['rule_pattern']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_CREATERESOURCERULEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_CREATERESOURCERULEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_CREATERESOURCERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_GETRESOURCERULEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_GETRESOURCERULEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETRESOURCERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_GETRESOURCERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['rule_pattern']._loaded_options = None
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['rule_pattern']._serialized_options = b'\212\3101\005<=100'
  _globals['_UPDATERESOURCERULEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERESOURCERULEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_UPDATERESOURCERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_DELETERESOURCERULEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DELETERESOURCERULEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETERESOURCERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_DELETERESOURCERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_DELETERESOURCERULEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DELETERESOURCERULEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETERESOURCERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_DELETERESOURCERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\017\022\r/cdn/v1/rules'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\032CreateResourceRuleMetadata\022\004Rule\202\323\344\223\002\022\"\r/cdn/v1/rules:\001*'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\031\022\027/cdn/v1/rules/{rule_id}'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\032UpdateResourceRuleMetadata\022\004Rule\202\323\344\223\002\0342\027/cdn/v1/rules/{rule_id}:\001*'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteResourceRuleMetadata\022\025google.protobuf.Empty\202\323\344\223\002\031*\027/cdn/v1/rules/{rule_id}'
  _globals['_LISTRESOURCERULESREQUEST']._serialized_start=266
  _globals['_LISTRESOURCERULESREQUEST']._serialized_end=327
  _globals['_LISTRESOURCERULESRESPONSE']._serialized_start=329
  _globals['_LISTRESOURCERULESRESPONSE']._serialized_end=398
  _globals['_CREATERESOURCERULEREQUEST']._serialized_start=401
  _globals['_CREATERESOURCERULEREQUEST']._serialized_end=583
  _globals['_CREATERESOURCERULEMETADATA']._serialized_start=585
  _globals['_CREATERESOURCERULEMETADATA']._serialized_end=673
  _globals['_GETRESOURCERULEREQUEST']._serialized_start=675
  _globals['_GETRESOURCERULEREQUEST']._serialized_end=759
  _globals['_UPDATERESOURCERULEREQUEST']._serialized_start=762
  _globals['_UPDATERESOURCERULEREQUEST']._serialized_end=961
  _globals['_UPDATERESOURCERULEMETADATA']._serialized_start=963
  _globals['_UPDATERESOURCERULEMETADATA']._serialized_end=1051
  _globals['_DELETERESOURCERULEREQUEST']._serialized_start=1053
  _globals['_DELETERESOURCERULEREQUEST']._serialized_end=1140
  _globals['_DELETERESOURCERULEMETADATA']._serialized_start=1142
  _globals['_DELETERESOURCERULEMETADATA']._serialized_end=1230
  _globals['_RESOURCERULESSERVICE']._serialized_start=1233
  _globals['_RESOURCERULESSERVICE']._serialized_end=2001
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DhcpOptions(google.protobuf.message.Message):
    """DHCP options for a subnet."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_IP_FIELD_NUMBER: builtins.int
    END_IP_FIELD_NUMBER: builtins.int
    start_ip: builtins.str
    """Start IP address of the DHCP range (inclusive)."""
    end_ip: builtins.str
    """End IP address of the DHCP range (inclusive)."""
    def __init__(
        self,
        *,
        start_ip: builtins.str = ...,
        end_ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["end_ip", b"end_ip", "start_ip", b"start_ip"]) -> None: ...

global___DhcpOptions = DhcpOptions
